package com.ai.ipu.cache.redis;

import com.ai.ipu.basic.log.ILogger;
import com.ai.ipu.basic.log.IpuLoggerFactory;
import com.ai.ipu.cache.CacheFactory;
import com.ai.ipu.cache.CacheFactory.CacheType;
import com.ai.ipu.cache.config.IpuCacheConfig;
import com.ai.ipu.cache.util.IpuCacheConstant;

import junit.framework.TestCase;

public class JedisCacheTest extends TestCase{
	private static final transient ILogger LOGGER = IpuLoggerFactory.createLogger(JedisCacheTest.class);
    private static final String STR_MESSAGE = "this is a test message";
    private static final String STR_VAL = "this is a test";
    private static final String STR_KEY = "key";
    private static final String CACHE_NAME = "data";
    private static final String STR_CHANNEL = "test";
    private static final long SECOND_TO_MS = 1000l;
    private static final int SLEEP_SECONDS = 3600;
    
    public void testPublish() throws Exception{
        IRedisCache cache = (IRedisCache)CacheFactory.getCache(CacheType.redis, CACHE_NAME);
        cache.publish(STR_CHANNEL, STR_MESSAGE);
    }
    
    public void testSubscribe()  throws Exception{
        IRedisCache cache = (IRedisCache)CacheFactory.getCache(CacheType.redis, CACHE_NAME);
        cache.subscribe(new PubSubListenerTest(), STR_CHANNEL);
        
        try{
            Thread.sleep(SLEEP_SECONDS * SECOND_TO_MS);
        }catch (Exception e)
        {
            
        }
        CacheFactory.close(CACHE_NAME, cache);
        
    }
    
    public void testPut() throws Exception{
        IRedisCache cache = null;
        try{
        	cache = (IRedisCache)CacheFactory.getCache(CacheType.redis, CACHE_NAME);
	        cache.put(STR_KEY, STR_VAL);
	        LOGGER.debug(STR_KEY+"="+cache.get(STR_KEY));
	        try{
	            Thread.sleep(10*SECOND_TO_MS);
	        }catch (Exception e)
	        {
	            ;
	        }
	        LOGGER.debug("after 10 seconds,"+STR_KEY+"="+cache.get(STR_KEY));
        }catch (Exception e)
        {
        	;
        }finally {
        	if (cache != null && IpuCacheConstant.ClientType.JEDIS_CLIENT.equalsIgnoreCase(IpuCacheConfig.getCacheDefaultAttr(CACHE_NAME,
                    IpuCacheConstant.Redis.CLIENT_TYPE, IpuCacheConstant.ClientType.JEDIS_CLIENT)))
        		cache.close();
        }
        
    }
    
    public void testClear() throws Exception{
        IRedisCache cache = (IRedisCache)CacheFactory.getCache(CacheType.redis, CACHE_NAME);
        cache.clear();
    }
}
